'use strict';

const AWS = require('aws-sdk');
// Set your region for future requests.

/**
 * CreateTable 
 * manage the createion of dynamodb tables
 */
class ManageTable {
    /**
     * @param TableName {string} required
     * @param primaryKeyName {string}  required
     * @param sortKeyName {string}  optional
     * @param throuput {number}  optional
     * @param profile {string}  optional
     * @returns Promise<{}> information about the created table!
     */
    static createTable(TableName, primaryKeyName, sortKeyName, throuput, profile, extra) {

        return new Promise((resolve, reject) => {

            // START credentials
            extra = extra || { region: 'us-east-1' };

            if(profile) {
                let credentials = new AWS.SharedIniFileCredentials({profile});
                AWS.config.credentials = credentials;
            }
            AWS.config.region = extra.region;
            // END credentials


            throuput = throuput || 5;
            let KeySchema = [];    
            let AttributeDefinitions = [];      
            KeySchema.push({ AttributeName: primaryKeyName, KeyType: "HASH"});  //Partition key
            AttributeDefinitions.push({ AttributeName: primaryKeyName, AttributeType: "S" });
            if(typeof sortKeyName === 'string') {
                KeySchema.push({ AttributeName: sortKeyName, KeyType: "RANGE" });  //Sort key
                AttributeDefinitions.push({ AttributeName: sortKeyName, AttributeType: "S" });
            }



            let dynamodb = new AWS.DynamoDB();

            var params = {
                TableName,
                KeySchema,
                AttributeDefinitions,
                ProvisionedThroughput: {       
                    ReadCapacityUnits: throuput, 
                    WriteCapacityUnits: throuput
                }
            };

            dynamodb.createTable(params, function(err, data) {
                if (err) {
                    console.error("Unable to create table. Error JSON:");
                    console.error(JSON.stringify(err, null, 2));
                    console.error("Unable to create table. Error JSON:");
                    return reject(err);
                } else {
                    return resolve(data);
                }
            });

        });
    }



    /**
     * @param TableName {string} required
     * @param primaryKeyName {string}  required
     * @param sortKeyName {string}  optional
     * @param throuput {number}  optional
     * @param profile {string}  optional
     * @returns Promise<{}> information about the created table!
     */
    static deleteTable(TableName, profile, extra) {

        return new Promise((resolve, reject) => {

            // START credentials
            extra = extra || { region: 'us-east-1' };

            if(profile) {
                let credentials = new AWS.SharedIniFileCredentials({profile});
                AWS.config.credentials = credentials;
            }
            AWS.config.region = extra.region;
            // END credentials

            let dynamodb = new AWS.DynamoDB();
            let params = {
                TableName
            };

            dynamodb.deleteTable(params, function(err, data) {
                if (err) {
                    console.error("Unable to create table. Error JSON:");
                    console.error(JSON.stringify(err, null, 2));
                    console.error("Unable to create table. Error JSON:");
                    return reject(err);
                } else {
                    return resolve(data);
                }
            });

        });
    }



}
module.exports = ManageTable;